@@ -1,4 +1,4 @@
-# $Id$
+# $Id: Content.pm 89 2007-10-04 20:28:06Z miyagawa $
 
 package XML::Atom::Content;
 use strict;
@@ -9,7 +9,6 @@ __PACKAGE__->mk_xml_attr_accessors(qw( lang base ));
 
 use Encode;
 use XML::Atom;
-use XML::Atom::Util qw( remove_default_ns hack_unicode_entity );
 use MIME::Base64 qw( encode_base64 decode_base64 );
 
 sub element_name { 'content' }
@@ -112,14 +111,13 @@ sub body {
                     }
                     $content->{__body} = '';
                     for my $n (@children) {
-                        remove_default_ns($n) if LIBXML;
                         $content->{__body} .= $n->toString(LIBXML ? 1 : 0);
                     }
                 } else {
                     $content->{__body} = LIBXML ? $elem->textContent : $elem->string_value;
                 }
                 if ($] >= 5.008) {
-                    $content->{__body} = hack_unicode_entity($content->{__body});
+                    Encode::_utf8_off($content->{__body}) unless $XML::Atom::ForceUnicode;
                 }
             } elsif ($mode eq 'base64') {
                 my $raw = decode_base64(LIBXML ? $elem->textContent : $elem->string_value);
